package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcTransferMapper;
import com.ruoyi.oa.domain.CmcTransfer;
import com.ruoyi.oa.service.ICmcTransferService;

/**
 * cmc员工调岗Service业务层处理
 * 
 * @author cmc
 * @date 2025-10-16
 */
@Service
public class CmcTransferServiceImpl implements ICmcTransferService 
{
    @Autowired
    private CmcTransferMapper cmcTransferMapper;

    /**
     * 查询cmc员工调岗
     * 
     * @param transferId cmc员工调岗主键
     * @return cmc员工调岗
     */
    @Override
    public CmcTransfer selectCmcTransferByTransferId(String transferId)
    {
        return cmcTransferMapper.selectCmcTransferByTransferId(transferId);
    }

    /**
     * 查询cmc员工调岗列表
     * 
     * @param cmcTransfer cmc员工调岗
     * @return cmc员工调岗
     */
    @Override
    public List<CmcTransfer> selectCmcTransferList(CmcTransfer cmcTransfer)
    {
        return cmcTransferMapper.selectCmcTransferList(cmcTransfer);
    }

    /**
     * 新增cmc员工调岗
     * 
     * @param cmcTransfer cmc员工调岗
     * @return 结果
     */
    @Override
    public int insertCmcTransfer(CmcTransfer cmcTransfer)
    {
        return cmcTransferMapper.insertCmcTransfer(cmcTransfer);
    }

    /**
     * 修改cmc员工调岗
     * 
     * @param cmcTransfer cmc员工调岗
     * @return 结果
     */
    @Override
    public int updateCmcTransfer(CmcTransfer cmcTransfer)
    {
        return cmcTransferMapper.updateCmcTransfer(cmcTransfer);
    }

    /**
     * 批量删除cmc员工调岗
     * 
     * @param transferIds 需要删除的cmc员工调岗主键
     * @return 结果
     */
    @Override
    public int deleteCmcTransferByTransferIds(String[] transferIds)
    {
        return cmcTransferMapper.deleteCmcTransferByTransferIds(transferIds);
    }

    /**
     * 删除cmc员工调岗信息
     * 
     * @param transferId cmc员工调岗主键
     * @return 结果
     */
    @Override
    public int deleteCmcTransferByTransferId(String transferId)
    {
        return cmcTransferMapper.deleteCmcTransferByTransferId(transferId);
    }
}
